/* a { color: black } */
/**/
/* */
div {
    /* inside */
    color: black;
    /* between */
    border-radius: 3px / 7px
    /* end */
}
/* b */

a {
    color: black;
    /* c */
}

.in/**/side {
  color: var/**/(--broken);
  font-family: sans-serif,/**/serif;
}
