let testOnReal = require('./test-on-real')
let eachTest = require('./each-test')
let testPath = require('./test-path')
let jsonify = require('./jsonify')

module.exports = { eachTest, jsonify, testOnReal, testPath }
